/*================================================================
 HMGMESSAGEBOX functions
 ================================================================*/
#include "hmg-include.ch"
#include "hbqtgui.ch"

/*................................................................
 MsgStop
 ................................................................*/
FUNCTION MsgBox( cMessage, cTitle, cInfoText, cDetailedText, cIcon )

   LOCAL xReturn, oMb
   
   WITH OBJECT oMb := HMGMESSAGEBOX():New()
      :MessageType   := MB_TYPE_BOX
      :Message       := cMessage
      :Title         := cTitle
      :InfoText      := cInfoText
      :DetailedText  := cDetailedText
      :Icon          := cIcon
   END WITH

   oMb:Activate()
   xReturn := oMb:KeyPressed()
   oMB := NIL
   hb_gcall()

RETURN xReturn

/*................................................................
 MsgInfo
 ................................................................*/
FUNCTION MsgInfo( cMessage, cTitle, cInfoText, cDetailedText, cIcon )

   LOCAL xReturn, oMb
   
   WITH OBJECT oMb := HMGMESSAGEBOX():New()
      :MessageType   := MB_TYPE_INFO
      :Message       := cMessage
      :Title         := cTitle
      :InfoText      := cInfoText
      :DetailedText  := cDetailedText
      :Icon          := cIcon
   END WITH

   oMb:Activate()
   xReturn := oMb:KeyPressed()
   oMB := NIL
   hb_gcall()

RETURN xReturn

/*................................................................
 MsgStop
 ................................................................*/
FUNCTION MsgStop( cMessage, cTitle, cInfoText, cDetailedText, cIcon )

   LOCAL xReturn, oMb
   
   WITH OBJECT oMb := HMGMESSAGEBOX():New()
      :MessageType   := MB_TYPE_STOP
      :Message       := cMessage
      :Title         := cTitle
      :InfoText      := cInfoText
      :DetailedText  := cDetailedText
      :Icon          := cIcon
   END WITH

   oMb:Activate()
   xReturn := oMb:KeyPressed()
   oMB := NIL
   hb_gcall()

RETURN xReturn

/*................................................................
 MsgExclamation
 ................................................................*/
FUNCTION MsgExclamation( cMessage, cTitle, cInfoText, cDetailedText, cIcon )

   LOCAL xReturn, oMb

   WITH OBJECT oMb := HMGMESSAGEBOX():New()
      :MessageType   := MB_TYPE_EXCLAMATION
      :Message       := cMessage
      :Title         := cTitle
      :InfoText      := cInfoText
      :DetailedText  := cDetailedText
      :Icon          := cIcon
   END WITH

   oMb:Activate()
   xReturn := oMb:KeyPressed()
   oMB := NIL
   hb_gcall()

RETURN xReturn

/*................................................................
 MsgYesNo
 ................................................................*/
FUNCTION MsgYesNo( cMessage, cTitle, cInfoText, cDetailedText, nDefaultButton, cIcon )

   LOCAL xReturn, oMb
   
   WITH OBJECT oMb := HMGMESSAGEBOX():New()
      :MessageType   := MB_TYPE_YESNO
      :Message       := cMessage
      :Title         := cTitle
      :InfoText      := cInfoText
      :DetailedText  := cDetailedText
      :Icon          := cIcon
      :DefaultButton := nDefaultButton
   END WITH

   oMb:Activate()
   xReturn := oMb:KeyPressed()
   oMB := NIL
   hb_gcall()

RETURN xReturn

/*================================================================
 HMGMESSAGEBOX class
 ================================================================*/
#include "hbclass.ch"
#include "common.ch"

CLASS HMGMESSAGEBOX FROM HMGBASEOBJ, HMGBASEINIT

// specialized Data
   DATA nDefaultButton                            INIT NIL
   DATA cDetailedText                             INIT NIL
   DATA cInfoText                                 INIT NIL
   DATA nKeyPressed                               INIT NIL
   DATA cMessage                                  INIT NIL
   DATA nMessageType                              INIT NIL

// Methods
   METHOD Activate
   METHOD Create
   METHOD New

// specialized Properties
   METHOD DefaultButton                           SETGET
   METHOD DetailedText                            SETGET
   METHOD InfoText                                SETGET
   METHOD KeyPressed                              INLINE ::nKeyPressed
   METHOD Message                                 SETGET
   METHOD MessageType                             SETGET

ENDCLASS

/*................................................................
 Methods - section
 ................................................................*/

/*---------------------------------------------------------------
 Activate
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:Activate()

// TO prevent more time activation
   IF ::lActivated == .T.
      RETURN NIL
   ENDIF

   ::Create()
   ::lActivated := .T.

// Show QtObject
   ::oQTObject:Show()

// Start Qt handling
   ::nKeyPressed := ::oQtObject:Exec()

RETURN NIL

/*---------------------------------------------------------------
 Create
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:Create()

   LOCAL nIconMessage, nButtons, nButtonHigh


// TO prevent more time creation
   IF ::lActivated == .T.
      RETURN NIL
   ENDIF

// TO prevent use without QT starting
   IF ::lQtStarted == .F.
      HMGAPPLICATION():Start()
   ENDIF

// TODO HMG errors
   IF ::lStdError == .T.
      ::sQtApplication:Exit()
      ::sQtApplication:Quit()
// TODO HmgStdErr LOG
      QUIT
   ENDIF

// InformativeText could be 0=text plain or 1=RichText. For a while, I prefer always RichText
   ::oQtObject:setTextFormat( 1 )
   ::nMessageType := IF( HB_ISNUMERIC( ::nMessageType ) == .T. .AND. ::nMessageType >= MB_TYPE_BOX .AND. ::nMessageType <= MB_TYPE_YESNOCANCEL, ::nMessageType, MB_TYPE_INFO )
   ::nDefaultButton := IF( HB_ISNUMERIC( ::nDefaultButton ) == .T., ::nDefaultButton, 1 )

   DO CASE
      CASE ::nMessageType == MB_TYPE_BOX
         nIconMessage   := QMessageBox_NoIcon
         nButtons       := QMessageBox_Ok
         nButtonHigh    := { QMessageBox_Ok }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_INFO
         nIconMessage   := QMessageBox_Information
         nButtons       := QMessageBox_Ok
         nButtonHigh    := { QMessageBox_Ok }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_STOP
         nIconMessage   := QMessageBox_Critical
         nButtons       := QMessageBox_Ok
         nButtonHigh    := { QMessageBox_Ok }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_EXCLAMATION
         nIconMessage   := QMessageBox_Warning
         nButtons       := QMessageBox_Ok
         nButtonHigh    := { QMessageBox_Ok }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_YESNO
         nIconMessage   := QMessageBox_Question
         nButtons       := hb_BitOr( QMessageBox_Yes, QMessageBox_No )
         nButtonHigh    := { QMessageBox_Yes, QMessageBox_No }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_OKCANCEL
         nIconMessage   := QMessageBox_Question
         nButtons       := hb_BitOr( QMessageBox_Ok, QMessageBox_Cancel )
         nButtonHigh    := { QMessageBox_Ok, QMessageBox_Cancel }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_RETRYCANCEL
         nIconMessage   := QMessageBox_Question
         nButtons       := hb_BitOr( QMessageBox_Retry, QMessageBox_Cancel )
         nButtonHigh    := { QMessageBox_Retry, QMessageBox_Cancel }[ ::nDefaultButton ]
      CASE ::nMessageType == MB_TYPE_YESNOCANCEL
         nIconMessage   := QMessageBox_Question
         nButtons       := hb_BitOr( QMessageBox_Yes, QMessageBox_No, QMessageBox_Cancel )
         nButtonHigh    := { QMessageBox_Yes, QMessageBox_No, QMessageBox_Cancel }[ ::nDefaultButton ]
   ENDCASE

   ::oQtObject:setIcon( nIconMessage )
   ::oQTObject:setStandardButtons( nButtons )
   ::oQTObject:setDefaultButton( nButtonHigh )
   ::oQTObject:setWindowFlags( Qt_Dialog )

RETURN NIL

/*---------------------------------------------------------------
 New
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:New( oParent )

// set-up parent in this order: parameter, current or default (last one is Qt QApplication():DeskTop()
   ::oParent := IF( hb_IsObject( oParent ), oParent, IF( hb_IsObject( ::oCurrentParent ), ::oCurrentParent, ::oDefaultParent ) )

// create QT object with its parent
   ::oQtObject      := QMessageBox( ::oParent:QtObject )

// inherit font
   ::oFont     := ::oParent:QtObject:Font()

RETURN Self

/*................................................................
 Properties - section
 ................................................................*/

/*---------------------------------------------------------------
 DefaultButton
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:DefaultButton( nArg1 )

   IF PCOUNT() == 0
      RETURN ::nDefaultButton
   ELSEIF VALTYPE( nArg1 ) == "N"
      ::nDefaultButton := nArg1
   ENDIF

RETURN NIL

/*---------------------------------------------------------------
 DetailedText
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:DetailedText( cArg1 )

   IF PCOUNT() == 0
      RETURN ::cDetailedText
   ELSEIF VALTYPE( cArg1 ) == "C"
      ::cDetailedText := cArg1
      ::oQTObject:setDetailedText( ::cDetailedText )
   ENDIF

RETURN NIL

/*---------------------------------------------------------------
 InfoText
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:InfoText( cArg1 )

   IF PCOUNT() == 0
      RETURN ::oQTObject:Text()
   ELSEIF VALTYPE( cArg1 ) == "C"
      ::cInfoText := cArg1
      ::oQTObject:setInformativeText( ::cInfoText )
   ENDIF

RETURN NIL

/*---------------------------------------------------------------
 Message
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:Message( cArg1 )

   IF PCOUNT() == 0
      RETURN ::oQTObject:Text()
   ELSEIF VALTYPE( cArg1 ) == "C"
      ::cMessage := cArg1
      ::oQTObject:setText( ::cMessage )
   ENDIF

RETURN NIL

/*---------------------------------------------------------------
 MessageType
 ---------------------------------------------------------------*/
METHOD HMGMESSAGEBOX:MessageType( nArg1 )

   IF PCOUNT() == 0
      RETURN ::nMessageType
   ELSEIF VALTYPE( nArg1 ) == "N"
      ::nMessageType := nArg1
   ENDIF

RETURN NIL
